# Demo data.

This should only be added to an empty database.

Tested in: tests/src/Utils/DemoDataLoader_Test.php

Copy _language.yaml.example to [langname].yaml, fill it in.  Create a story .txt file for the lang too.